package com.jeeplus.test.wdt.merchantCompany.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jeeplus.test.wdt.merchantCompany.domain.MerchantCompany;
import com.jeeplus.test.wdt.merchantCompany.service.dto.MerchantCompanyDTO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 入驻商家mapper
 * @author: 徐滕
 * @version: 2024-01-04 10:59
 */
public interface MerchantCompanyMapper extends BaseMapper<MerchantCompany> {


    /**
     * 根据id获取入驻商家信息
     * @param id
     * @return
     */
    MerchantCompanyDTO findById(String id);

    /**
     * 根据商户名称获取入驻商家信息
     * @param companyName
     * @return
     */
    MerchantCompanyDTO getByCompanyName(String companyName);


    /**
     * 获取入驻商家表单列表
     *
     * @param queryWrapper
     * @return
     */
    IPage<MerchantCompanyDTO> findList(Page<MerchantCompanyDTO> page, @Param(Constants.WRAPPER) QueryWrapper queryWrapper);


    /**
     * 获取入驻商家表单列表
     *
     * @param queryWrapper
     * @return
     */
    List<MerchantCompanyDTO> getListJson(@Param(Constants.WRAPPER) QueryWrapper queryWrapper);

    /**
     * 根据商户id删除入驻平台信息
     * @param id
     */
    void deleteSettledPlatform(String id);

    /**
     * 根据商户id和入驻平台id新增数据
     * @param id
     * @param settledPlatformId
     */
    void insertSettledPlatform(@Param("id") String id ,@Param("settledPlatformId") String settledPlatformId);

    /**
     * 根据商户id删除入驻产品信息
     * @param id
     */
    void deleteMerchantProduct(String id);

    /**
     * 根据商户id和入驻产品id新增数据
     * @param id
     * @param merchantProductId
     */
    void insertMerchantProduct(@Param("id") String id ,@Param("merchantProductId") String merchantProductId);

    /**
     * 根据商户id删除入驻公司类型信息
     * @param id
     */
    void deleteMerchantCompanyType(String id);

    /**
     * 根据商户id和入驻公司类型id新增数据
     * @param id
     * @param merchantCompanyType
     */
    void insertMerchantCompanyType(@Param("id") String id ,@Param("merchantCompanyType") String merchantCompanyType);
}
